@@ -138,9 +138,7 @@
 
 #include <ctype.h>
 
-#if HAVE_STDLIB_H
-# include <stdlib.h> /* for `free'; used by Bison 1.27 */
-#endif
+#include <stdlib.h> /* for `free'; used by Bison 1.27 */
 
 #if STDC_HEADERS || (! defined isascii && ! HAVE_ISASCII)
 # define IN_CTYPE_DOMAIN(c) 1
@@ -162,9 +160,7 @@
    of `digit' even when the host does not conform to POSIX.  */
 #define ISDIGIT(c) ((unsigned) (c) - '0' <= 9)
 
-#if STDC_HEADERS || HAVE_STRING_H
-# include <string.h>
-#endif
+#include <string.h>
 
 #if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 8) || __STRICT_ANSI__
 # define __attribute__(x)
@@ -270,13 +266,13 @@ static int yylex ();
 #endif
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 171 "getdate.y"
+#line 167 "getdate.y"
 typedef union YYSTYPE {
   int intval;
   textint textintval;
 } YYSTYPE;
 /* Line 191 of yacc.c.  */
-#line 280 "getdate.c"
+#line 276 "getdate.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -288,7 +284,7 @@ typedef union YYSTYPE {
 
 
 /* Line 214 of yacc.c.  */
-#line 292 "getdate.c"
+#line 288 "getdate.c"
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
@@ -476,12 +472,12 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned short yyrline[] =
 {
-       0,   187,   187,   189,   193,   195,   197,   199,   201,   203,
-     205,   209,   216,   223,   231,   238,   250,   252,   257,   259,
-     261,   266,   271,   276,   284,   289,   309,   316,   324,   332,
-     337,   343,   348,   357,   366,   370,   372,   374,   376,   378,
-     380,   382,   384,   386,   388,   390,   392,   394,   396,   398,
-     400,   402,   404,   409,   446,   447
+       0,   183,   183,   185,   189,   191,   193,   195,   197,   199,
+     201,   205,   212,   219,   227,   234,   246,   248,   253,   255,
+     257,   262,   267,   272,   280,   285,   305,   312,   320,   328,
+     333,   339,   344,   353,   362,   366,   368,   370,   372,   374,
+     376,   378,   380,   382,   384,   386,   388,   390,   392,   394,
+     396,   398,   400,   405,   442,   443
 };
 #endif
 
@@ -1220,37 +1216,37 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 194 "getdate.y"
+#line 190 "getdate.y"
     { PC.times_seen++; }
     break;
 
   case 5:
-#line 196 "getdate.y"
+#line 192 "getdate.y"
     { PC.local_zones_seen++; }
     break;
 
   case 6:
-#line 198 "getdate.y"
+#line 194 "getdate.y"
     { PC.zones_seen++; }
     break;
 
   case 7:
-#line 200 "getdate.y"
+#line 196 "getdate.y"
     { PC.dates_seen++; }
     break;
 
   case 8:
-#line 202 "getdate.y"
+#line 198 "getdate.y"
     { PC.days_seen++; }
     break;
 
   case 9:
-#line 204 "getdate.y"
+#line 200 "getdate.y"
     { PC.rels_seen++; }
     break;
 
   case 11:
-#line 210 "getdate.y"
+#line 206 "getdate.y"
     {
 	PC.hour = yyvsp[-1].textintval.value;
 	PC.minutes = 0;
@@ -1260,7 +1256,7 @@ yyreduce:
     break;
 
   case 12:
-#line 217 "getdate.y"
+#line 213 "getdate.y"
     {
 	PC.hour = yyvsp[-3].textintval.value;
 	PC.minutes = yyvsp[-1].textintval.value;
@@ -1270,7 +1266,7 @@ yyreduce:
     break;
 
   case 13:
-#line 224 "getdate.y"
+#line 220 "getdate.y"
     {
 	PC.hour = yyvsp[-3].textintval.value;
 	PC.minutes = yyvsp[-1].textintval.value;
@@ -1281,7 +1277,7 @@ yyreduce:
     break;
 
   case 14:
-#line 232 "getdate.y"
+#line 228 "getdate.y"
     {
 	PC.hour = yyvsp[-5].textintval.value;
 	PC.minutes = yyvsp[-3].textintval.value;
@@ -1291,7 +1287,7 @@ yyreduce:
     break;
 
   case 15:
-#line 239 "getdate.y"
+#line 235 "getdate.y"
     {
 	PC.hour = yyvsp[-5].textintval.value;
 	PC.minutes = yyvsp[-3].textintval.value;
@@ -1303,32 +1299,32 @@ yyreduce:
     break;
 
   case 16:
-#line 251 "getdate.y"
+#line 247 "getdate.y"
     { PC.local_isdst = yyvsp[0].intval; }
     break;
 
   case 17:
-#line 253 "getdate.y"
+#line 249 "getdate.y"
     { PC.local_isdst = yyvsp[-1].intval < 0 ? 1 : yyvsp[-1].intval + 1; }
     break;
 
   case 18:
-#line 258 "getdate.y"
+#line 254 "getdate.y"
     { PC.time_zone = yyvsp[0].intval; }
     break;
 
   case 19:
-#line 260 "getdate.y"
+#line 256 "getdate.y"
     { PC.time_zone = yyvsp[0].intval + 60; }
     break;
 
   case 20:
-#line 262 "getdate.y"
+#line 258 "getdate.y"
     { PC.time_zone = yyvsp[-1].intval + 60; }
     break;
 
   case 21:
-#line 267 "getdate.y"
+#line 263 "getdate.y"
     {
 	PC.day_ordinal = 1;
 	PC.day_number = yyvsp[0].intval;
@@ -1336,7 +1332,7 @@ yyreduce:
     break;
 
   case 22:
-#line 272 "getdate.y"
+#line 268 "getdate.y"
     {
 	PC.day_ordinal = 1;
 	PC.day_number = yyvsp[-1].intval;
@@ -1344,7 +1340,7 @@ yyreduce:
     break;
 
   case 23:
-#line 277 "getdate.y"
+#line 273 "getdate.y"
     {
 	PC.day_ordinal = yyvsp[-1].textintval.value;
 	PC.day_number = yyvsp[0].intval;
@@ -1352,7 +1348,7 @@ yyreduce:
     break;
 
   case 24:
-#line 285 "getdate.y"
+#line 281 "getdate.y"
     {
 	PC.month = yyvsp[-2].textintval.value;
 	PC.day = yyvsp[0].textintval.value;
@@ -1360,7 +1356,7 @@ yyreduce:
     break;
 
   case 25:
-#line 290 "getdate.y"
+#line 286 "getdate.y"
     {
 	/* Interpret as YYYY/MM/DD if the first value has 4 or more digits,
 	   otherwise as MM/DD/YY.
@@ -1383,7 +1379,7 @@ yyreduce:
     break;
 
   case 26:
-#line 310 "getdate.y"
+#line 306 "getdate.y"
     {
 	/* ISO 8601 format.  YYYY-MM-DD.  */
 	PC.year = yyvsp[-2].textintval;
@@ -1393,7 +1389,7 @@ yyreduce:
     break;
 
   case 27:
-#line 317 "getdate.y"
+#line 313 "getdate.y"
     {
 	/* e.g. 17-JUN-1992.  */
 	PC.day = yyvsp[-2].textintval.value;
@@ -1404,7 +1400,7 @@ yyreduce:
     break;
 
   case 28:
-#line 325 "getdate.y"
+#line 321 "getdate.y"
     {
 	/* e.g. JUN-17-1992.  */
 	PC.month = yyvsp[-2].intval;
@@ -1415,7 +1411,7 @@ yyreduce:
     break;
 
   case 29:
-#line 333 "getdate.y"
+#line 329 "getdate.y"
     {
 	PC.month = yyvsp[-1].intval;
 	PC.day = yyvsp[0].textintval.value;
@@ -1423,7 +1419,7 @@ yyreduce:
     break;
 
   case 30:
-#line 338 "getdate.y"
+#line 334 "getdate.y"
     {
 	PC.month = yyvsp[-3].intval;
 	PC.day = yyvsp[-2].textintval.value;
@@ -1432,7 +1428,7 @@ yyreduce:
     break;
 
   case 31:
-#line 344 "getdate.y"
+#line 340 "getdate.y"
     {
 	PC.day = yyvsp[-1].textintval.value;
 	PC.month = yyvsp[0].intval;
@@ -1440,7 +1436,7 @@ yyreduce:
     break;
 
   case 32:
-#line 349 "getdate.y"
+#line 345 "getdate.y"
     {
 	PC.day = yyvsp[-2].textintval.value;
 	PC.month = yyvsp[-1].intval;
@@ -1449,7 +1445,7 @@ yyreduce:
     break;
 
   case 33:
-#line 358 "getdate.y"
+#line 354 "getdate.y"
     {
 	PC.rel_seconds = -PC.rel_seconds;
 	PC.rel_minutes = -PC.rel_minutes;
@@ -1461,97 +1457,97 @@ yyreduce:
     break;
 
   case 35:
-#line 371 "getdate.y"
+#line 367 "getdate.y"
     { PC.rel_year += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 36:
-#line 373 "getdate.y"
+#line 369 "getdate.y"
     { PC.rel_year += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 37:
-#line 375 "getdate.y"
+#line 371 "getdate.y"
     { PC.rel_year += yyvsp[0].intval; }
     break;
 
   case 38:
-#line 377 "getdate.y"
+#line 373 "getdate.y"
     { PC.rel_month += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 39:
-#line 379 "getdate.y"
+#line 375 "getdate.y"
     { PC.rel_month += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 40:
-#line 381 "getdate.y"
+#line 377 "getdate.y"
     { PC.rel_month += yyvsp[0].intval; }
     break;
 
   case 41:
-#line 383 "getdate.y"
+#line 379 "getdate.y"
     { PC.rel_day += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 42:
-#line 385 "getdate.y"
+#line 381 "getdate.y"
     { PC.rel_day += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 43:
-#line 387 "getdate.y"
+#line 383 "getdate.y"
     { PC.rel_day += yyvsp[0].intval; }
     break;
 
   case 44:
-#line 389 "getdate.y"
+#line 385 "getdate.y"
     { PC.rel_hour += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 45:
-#line 391 "getdate.y"
+#line 387 "getdate.y"
     { PC.rel_hour += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 46:
-#line 393 "getdate.y"
+#line 389 "getdate.y"
     { PC.rel_hour += yyvsp[0].intval; }
     break;
 
   case 47:
-#line 395 "getdate.y"
+#line 391 "getdate.y"
     { PC.rel_minutes += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 48:
-#line 397 "getdate.y"
+#line 393 "getdate.y"
     { PC.rel_minutes += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 49:
-#line 399 "getdate.y"
+#line 395 "getdate.y"
     { PC.rel_minutes += yyvsp[0].intval; }
     break;
 
   case 50:
-#line 401 "getdate.y"
+#line 397 "getdate.y"
     { PC.rel_seconds += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 51:
-#line 403 "getdate.y"
+#line 399 "getdate.y"
     { PC.rel_seconds += yyvsp[-1].textintval.value * yyvsp[0].intval; }
     break;
 
   case 52:
-#line 405 "getdate.y"
+#line 401 "getdate.y"
     { PC.rel_seconds += yyvsp[0].intval; }
     break;
 
   case 53:
-#line 410 "getdate.y"
+#line 406 "getdate.y"
     {
 	if (PC.dates_seen
 	    && ! PC.rels_seen && (PC.times_seen || 2 < yyvsp[0].textintval.digits))
@@ -1587,12 +1583,12 @@ yyreduce:
     break;
 
   case 54:
-#line 446 "getdate.y"
+#line 442 "getdate.y"
     { yyval.intval = MER24; }
     break;
 
   case 55:
-#line 448 "getdate.y"
+#line 444 "getdate.y"
     { yyval.intval = yyvsp[0].intval; }
     break;
 
@@ -1600,7 +1596,7 @@ yyreduce:
     }
 
 /* Line 999 of yacc.c.  */
-#line 1604 "getdate.c"
+#line 1600 "getdate.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1806,7 +1802,7 @@ yyreturn:
 }
 
 
-#line 451 "getdate.y"
+#line 447 "getdate.y"
 
 
 /* Include this file down here because bison inserts code above which
