@@ -1,5 +1,7 @@
 /* Determine whether two file names refer to the same file.
-   Copyright (C) 1997-2000, 2003 Free Software Foundation, Inc.
+
+   Copyright (C) 1997, 1998, 1999, 2000, 2003 Free Software
+   Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -18,7 +20,6 @@
 #ifndef SAME_H_
 # define SAME_H_ 1
 
-int
-same_name (const char *source, const char *dest);
+int same_name (const char *source, const char *dest);
 
 #endif /* SAME_H_ */
