@@ -1,5 +1,5 @@
 /* xstrtoimax.c -- A more useful interface to strtoimax.
-   Copyright 2001 Free Software Foundation, Inc.
+   Copyright (C) 2001, 2003 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,4 +30,8 @@
 #define __strtol strtoimax
 #define __strtol_t intmax_t
 #define __xstrtol xstrtoimax
+#ifdef INTMAX_MAX
+# define STRTOL_T_MINIMUM INTMAX_MIN
+# define STRTOL_T_MAXIMUM INTMAX_MAX
+#endif
 #include "xstrtol.c"
