@@ -1,5 +1,5 @@
 /* mkfifo -- make fifo's (named pipes)
-   Copyright (C) 90, 91, 1995-2003 Free Software Foundation, Inc.
+   Copyright (C) 90, 91, 1995-2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -47,7 +47,7 @@ static struct option const longopts[] =
 void
 usage (int status)
 {
-  if (status != 0)
+  if (status != EXIT_SUCCESS)
     fprintf (stderr, _("Try `%s --help' for more information.\n"),
 	     program_name);
   else
@@ -91,7 +91,7 @@ main (int argc, char **argv)
   specified_mode = NULL;
 
 #ifndef S_ISFIFO
-  error (4, 0, _("fifo files not supported"));
+  error (EXIT_FAILURE, 0, _("fifo files not supported"));
 #else
   while ((optc = getopt_long (argc, argv, "m:", longopts, NULL)) != -1)
     {
