@@ -1,6 +1,6 @@
 /* Permuted index for GNU, with keywords in their context.
    Copyright (C) 1990, 1991, 1993, 1998-2003 Free Software Foundation, Inc.
-   Franois Pinard <pinard@iro.umontreal.ca>, 1988.
+   François Pinard <pinard@iro.umontreal.ca>, 1988.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-   Franois Pinard <pinard@iro.umontreal.ca> */
+   François Pinard <pinard@iro.umontreal.ca> */
 
 #include <config.h>
 
@@ -25,7 +25,6 @@
 #include <sys/types.h>
 #include "system.h"
 #include "argmatch.h"
-#include "bumpalloc.h"
 #include "diacrit.h"
 #include "error.h"
 #include "regex.h"
@@ -33,7 +32,10 @@
 /* The official name of this program (e.g., no `g' prefix).  */
 #define PROGRAM_NAME "ptx"
 
-#define AUTHORS "Franois Pinard"
+/* Note to translator: Please translate "F. Pinard" to "François
+   Pinard" if "ç" (c-with-cedilla) is available in the
+   translation's character set and encoding.  */
+#define AUTHORS _("F. Pinard")
 
 /* Number of possible characters in a byte.  */
 #define CHAR_SET_SIZE 256
@@ -114,7 +116,8 @@ WORD;
 typedef struct
   {
     WORD *start;		/* array of WORDs */
-    size_t length;		/* number of entries */
+    size_t alloc;		/* allocated length */
+    size_t length;		/* number of used entries */
   }
 WORD_TABLE;
 
@@ -157,9 +160,6 @@ int reference_max_width;
 WORD_TABLE ignore_table;	/* table of words to ignore */
 WORD_TABLE only_table;		/* table of words to select */
 
-#define ALLOC_NEW_WORD(table) \
-  BUMP_ALLOC ((table)->start, (table)->length, 8, WORD)
-
 /* Source text table, and scanning macros.  */
 
 int number_input_files;		/* number of text input files */
@@ -239,10 +239,9 @@ OCCURS;
    being, there is no such multiple language support.  */
 
 OCCURS *occurs_table[1];	/* all words retained from the read text */
+size_t occurs_alloc[1];		/* allocated size of occurs_table */
 size_t number_of_occurs[1];	/* number of used slots in occurs_table */
 
-#define ALLOC_NEW_OCCURS(language) \
-  BUMP_ALLOC (occurs_table[language], number_of_occurs[language], 9, OCCURS)
 
 /* Communication among output routines.  */
 
@@ -395,8 +394,7 @@ alloc_and_compile_regex (const char *string)
   struct re_pattern_buffer *pattern; /* newly allocated structure */
   const char *message;		/* error message returned by regex.c */
 
-  pattern = (struct re_pattern_buffer *)
-    xmalloc (sizeof (struct re_pattern_buffer));
+  pattern = xmalloc (sizeof *pattern);
   memset (pattern, 0, sizeof (struct re_pattern_buffer));
 
   pattern->buffer = NULL;
@@ -764,6 +762,7 @@ digest_word_file (const char *file_name, WORD_TABLE *table)
   swallow_file_in_memory (file_name, &file_contents);
 
   table->start = NULL;
+  table->alloc = 0;
   table->length = 0;
 
   /* Read the whole file.  */
@@ -782,7 +781,15 @@ digest_word_file (const char *file_name, WORD_TABLE *table)
 
       if (cursor > word_start)
 	{
-	  ALLOC_NEW_WORD (table);
+	  if (table->length == table->alloc)
+	    {
+	      if ((SIZE_MAX / sizeof *table->start - 1) / 2 < table->alloc)
+		xalloc_die ();
+	      table->alloc = table->alloc * 2 + 1;
+	      table->start = xrealloc (table->start,
+				       table->alloc * sizeof *table->start);
+	    }
+
 	  table->start[table->length].start = word_start;
 	  table->start[table->length].size = cursor - word_start;
 	  table->length++;
@@ -994,7 +1001,16 @@ find_occurs_in_text (void)
 	     proper allocation of the next OCCURS, and make a pointer to
 	     where it will be constructed.  */
 
-	  ALLOC_NEW_OCCURS (0);
+	  if (number_of_occurs[0] == occurs_alloc[0])
+	    {
+	      if ((SIZE_MAX / sizeof *occurs_table[0] - 1) / 2
+		  < occurs_alloc[0])
+		xalloc_die ();
+	      occurs_alloc[0] = occurs_alloc[0] * 2 + 1;
+	      occurs_table[0] = xrealloc (occurs_table[0],
+					  occurs_alloc[0] * sizeof *occurs_table[0]);
+	    }
+
 	  occurs_cursor = occurs_table[0] + number_of_occurs[0];
 
 	  /* Define the refence field, if any.  */
@@ -1898,6 +1914,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
 \n\
 With no FILE or if FILE is -, read Standard Input.  `-F /' by default.\n\
 "), stdout);
+      printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
     }
   exit (status);
 }
@@ -2090,18 +2107,16 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n"),
 
       /* No more argument simply means: read standard input.  */
 
-      input_file_name = xmalloc (sizeof (const char *));
-      file_line_count = xmalloc (sizeof (int));
+      input_file_name = xmalloc (sizeof *input_file_name);
+      file_line_count = xmalloc (sizeof *file_line_count);
       number_input_files = 1;
       input_file_name[0] = NULL;
     }
   else if (gnu_extensions)
     {
       number_input_files = argc - optind;
-      input_file_name
-	= xmalloc (number_input_files * sizeof (const char *));
-      file_line_count
-	= xmalloc (number_input_files * sizeof (int));
+      input_file_name = xmalloc (number_input_files * sizeof *input_file_name);
+      file_line_count = xmalloc (number_input_files * sizeof *file_line_count);
 
       for (file_index = 0; file_index < number_input_files; file_index++)
 	{
@@ -2119,8 +2134,8 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n"),
       /* There is one necessary input file.  */
 
       number_input_files = 1;
-      input_file_name = xmalloc (sizeof (const char *));
-      file_line_count = xmalloc (sizeof (int));
+      input_file_name = xmalloc (sizeof *input_file_name);
+      file_line_count = xmalloc (sizeof *file_line_count);
       if (!*argv[optind] || strcmp (argv[optind], "-") == 0)
 	input_file_name[0] = NULL;
       else
