@@ -1,5 +1,5 @@
 /* sum -- checksum and count the blocks in a file
-   Copyright (C) 86, 89, 91, 1995-2002 Free Software Foundation, Inc.
+   Copyright (C) 86, 89, 91, 1995-2002, 2004 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -25,7 +25,6 @@
 #include <sys/types.h>
 #include <getopt.h>
 #include "system.h"
-#include "closeout.h"
 #include "error.h"
 #include "human.h"
 #include "safe-read.h"
@@ -33,7 +32,7 @@
 /* The official name of this program (e.g., no `g' prefix).  */
 #define PROGRAM_NAME "sum"
 
-#define AUTHORS N_ ("Kayvan Aghaiepour and David MacKenzie")
+#define AUTHORS "Kayvan Aghaiepour", "David MacKenzie"
 
 /* The name this program was run with. */
 char *program_name;
@@ -52,7 +51,7 @@ static struct option const longopts[] =
 void
 usage (int status)
 {
-  if (status != 0)
+  if (status != EXIT_SUCCESS)
     fprintf (stderr, _("Try `%s --help' for more information.\n"),
 	     program_name);
   else
@@ -75,7 +74,7 @@ With no FILE, or when FILE is -, read standard input.\n\
 "), stdout);
       printf (_("\nReport bugs to <%s>.\n"), PACKAGE_BUGREPORT);
     }
-  exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
+  exit (status);
 }
 
 /* Calculate and print the rotated checksum and the size in 1K blocks
@@ -133,7 +132,7 @@ bsd_sum_file (const char *file, int print_name)
     }
 
   printf ("%05d %5s", checksum,
-	  human_readable_inexact (total_bytes, hbuf, 1, 1024, human_ceiling));
+	  human_readable (total_bytes, hbuf, human_ceiling, 1, 1024));
   if (print_name > 1)
     printf (" %s", file);
   putchar ('\n');
@@ -207,7 +206,7 @@ sysv_sum_file (const char *file, int print_name)
   checksum = (r & 0xffff) + (r >> 16);
 
   printf ("%d %s", checksum,
-	  human_readable_inexact (total_bytes, hbuf, 1, 512, human_ceiling));
+	  human_readable (total_bytes, hbuf, human_ceiling, 1, 512));
   if (print_name)
     printf (" %s", file);
   putchar ('\n');
@@ -221,8 +220,9 @@ main (int argc, char **argv)
   int errors = 0;
   int optc;
   int files_given;
-  int (*sum_func) PARAMS ((const char *, int)) = bsd_sum_file;
+  int (*sum_func) (const char *, int) = bsd_sum_file;
 
+  initialize_main (&argc, &argv);
   program_name = argv[0];
   setlocale (LC_ALL, "");
   bindtextdomain (PACKAGE, LOCALEDIR);
